
import { useEffect } from 'react';
import { Link } from 'react-router-dom';
import { ArrowRight, Mail, Phone, User } from 'lucide-react';
import Navbar from '@/components/Navbar';
import Hero from '@/components/Hero';
import Features from '@/components/Features';
import Footer from '@/components/Footer';
import BookDemo from '@/components/BookDemo';

const Index = () => {
  // Scroll to top on load
  useEffect(() => {
    window.scrollTo(0, 0);
  }, []);

  return (
    <div className="min-h-screen bg-background">
      <Navbar />
      
      <main>
        <Hero />
        <Features />
        
        {/* Book Demo Section */}
        <BookDemo />
        
        <section className="section-container">
          <div className="glass-panel p-8 md:p-12 text-center">
            <h2 className="heading-md mb-4 animate-fade-up">Ready to Get Started?</h2>
            <p className="text-lg text-muted-foreground mb-6 max-w-2xl mx-auto animate-fade-up" style={{ animationDelay: '0.1s' }}>
              Empower your financial decision-making with our advanced credit risk assessment tool. Get started with your first prediction in minutes.
            </p>
            <Link 
              to="/assessment" 
              className="button-primary inline-flex items-center gap-2 animate-fade-up animate-pulse shadow-lg shadow-brand-red/20 hover:shadow-brand-red/40 transition-all duration-500"
              style={{ animationDelay: '0.2s' }}
            >
              Start a New Assessment
              <ArrowRight size={18} />
            </Link>
          </div>
        </section>

        {/* Contact Section */}
        <section className="bg-muted/30 py-16">
          <div className="container max-w-6xl mx-auto px-4">
            <div className="max-w-3xl mx-auto text-center mb-12">
              <h2 className="heading-md mb-4">Contact Us</h2>
              <p className="text-muted-foreground">
                For information about our dataset, model, or any other inquiries, please reach out to CIFT's leadership.
              </p>
            </div>
            
            <div className="glass-panel p-8 max-w-2xl mx-auto">
              <div className="flex flex-col items-center text-center">
                <div className="w-20 h-20 rounded-full bg-brand-red/10 flex items-center justify-center mb-4">
                  <User size={32} className="text-brand-red" />
                </div>
                
                <h3 className="text-xl font-medium mb-1">Professor MS Sobhan</h3>
                <p className="text-brand-red mb-4">Founder & CEO of CIFT</p>
                
                <div className="space-y-3 w-full max-w-xs">
                  <a 
                    href="mailto:ceo@ciftbd.com" 
                    className="flex items-center justify-center gap-3 p-3 rounded-lg border border-muted hover:bg-muted/50 hover:shadow-md transition-all duration-300 w-full"
                  >
                    <Mail size={18} className="text-brand-red" />
                    <span>ceo@ciftbd.com</span>
                  </a>
                  
                  <a 
                    href="tel:+8801754459594" 
                    className="flex items-center justify-center gap-3 p-3 rounded-lg border border-muted hover:bg-muted/50 hover:shadow-md transition-all duration-300 w-full"
                  >
                    <Phone size={18} className="text-brand-red" />
                    <span>+880 1754 459594</span>
                  </a>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
      
      <Footer />
    </div>
  );
};

export default Index;
